===========
trame-vtk3d
===========

Trame wrapper to WASM bundle of VTK from `dicehub <https://dicehub.com/welcome>`_

License
--------

The trame widget is released under Apache Software License.

Installation
-------------

.. code-block:: console

    pip install trame-vtk3d


Development
------------
Build and install the Vue components

.. code-block:: console

    cd vue-components
    npm i
    npm run build
    cd -

Install the application

.. code-block:: console

    pip install -e .
